/*
  Copyright 2021 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.friend.model

import com.kakao.sdk.partner.friend.util.FilterSearchable

sealed class Item {
    data class Header(val title: String) : Item()
    object Divider : Item()
    object EmptySearchResult : Item()
    data class User(
        val nickname: String?,
        val profileImageUrl: String?,
        val uuid: String?,
        val msgAllowed: Boolean = true,
        var isChecked: Boolean = false
    ) : Item(), FilterSearchable {
        override fun equals(other: Any?): Boolean {
            if (other is User) {
                return uuid == other.uuid
            }
            return super.equals(other)
        }

        override fun hashCode(): Int {
            return super.hashCode()
        }

        override val filterKeyword: String
            get() = nickname ?: ""
    }
}